@@ -9,9 +9,11 @@ from returns.result import safe
 from piri_cli.common import read_file, write_file
 
 
-def parse_args():
+def parse_args() -> argparse.Namespace:
+    """Parse piri args."""
+    desc = 'Transforms input json with provided cfg file to output.json'
     parser = argparse.ArgumentParser(
-        description='Transforms input json with provided cfg file to output.json',
+        description=desc,
     )
 
     parser.add_argument(
@@ -46,7 +48,7 @@ def on_failure(failure):
 
 
 def main():
-
+    """Run piri with given args."""
     args = parse_args()
 
     configuration = read_file(
